"""
Module implementing classes related to pokemon moves
"""
from dataclasses import dataclass


@dataclass
class Move:
    name: str
    move_type: str
    category: str
    pp: str
    power: str
    acc: str
    index: int

    @classmethod
    def from_name(cls, name: str) -> "Move":
        data = NAME_TO_DATA[name]

        return cls(
            name=name,
            move_type=data["type"],
            category=data["category"],
            pp=data["pp"],
            power=data["power"],
            acc=data["acc"],
            index=data["index"],
        )


MOVES = {
    0: {"name": "-", "type": "-", "category": "-", "pp": 0, "power": 0, "acc": "-"},
    1: {
        "name": "Pound",
        "type": "Normal",
        "category": "Physical",
        "pp": 35,
        "power": 40,
        "acc": "100%",
    },
    2: {
        "name": "Karate Chop",
        "type": "Fighting",
        "category": "Physical",
        "pp": 25,
        "power": 50,
        "acc": "100%",
    },
    3: {
        "name": "Double Slap",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": 15,
        "acc": "85%",
    },
    4: {
        "name": "Comet Punch",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": 18,
        "acc": "85%",
    },
    5: {
        "name": "Mega Punch",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": 80,
        "acc": "85%",
    },
    6: {
        "name": "Pay Day",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": 40,
        "acc": "100%",
    },
    7: {
        "name": "Fire Punch",
        "type": "Fire",
        "category": "Physical",
        "pp": 15,
        "power": 75,
        "acc": "100%",
    },
    8: {
        "name": "Ice Punch",
        "type": "Ice",
        "category": "Physical",
        "pp": 15,
        "power": 75,
        "acc": "100%",
    },
    9: {
        "name": "Thunder Punch",
        "type": "Electric",
        "category": "Physical",
        "pp": 15,
        "power": 75,
        "acc": "100%",
    },
    10: {
        "name": "Scratch",
        "type": "Normal",
        "category": "Physical",
        "pp": 35,
        "power": 40,
        "acc": "100%",
    },
    11: {
        "name": "Vise Grip",
        "type": "Normal",
        "category": "Physical",
        "pp": 30,
        "power": 55,
        "acc": "100%",
    },
    12: {
        "name": "Guillotine",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "—",
        "acc": "30%",
    },
    13: {
        "name": "Razor Wind",
        "type": "Normal",
        "category": "Special",
        "pp": 10,
        "power": "80",
        "acc": "100%",
    },
    14: {
        "name": "Swords Dance",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    15: {
        "name": "Cut",
        "type": "Normal",
        "category": "Physical",
        "pp": 30,
        "power": "50",
        "acc": "95%",
    },
    16: {
        "name": "Gust",
        "type": "Flying",
        "category": "Special",
        "pp": 35,
        "power": "40",
        "acc": "100%",
    },
    17: {
        "name": "Wing Attack",
        "type": "Flying",
        "category": "Physical",
        "pp": 35,
        "power": "60",
        "acc": "100%",
    },
    18: {
        "name": "Whirlwind",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    19: {
        "name": "Fly",
        "type": "Flying",
        "category": "Physical",
        "pp": 15,
        "power": "90",
        "acc": "95%",
    },
    20: {
        "name": "Bind",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "15",
        "acc": "85%",
    },
    21: {
        "name": "Slam",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "80",
        "acc": "75%",
    },
    22: {
        "name": "Vine Whip",
        "type": "Grass",
        "category": "Physical",
        "pp": 25,
        "power": "45",
        "acc": "100%",
    },
    23: {
        "name": "Stomp",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    24: {
        "name": "Double Kick",
        "type": "Fighting",
        "category": "Physical",
        "pp": 30,
        "power": "30",
        "acc": "100%",
    },
    25: {
        "name": "Mega Kick",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "120",
        "acc": "75%",
    },
    26: {
        "name": "Jump Kick",
        "type": "Fighting",
        "category": "Physical",
        "pp": 10,
        "power": "100",
        "acc": "95%",
    },
    27: {
        "name": "Rolling Kick",
        "type": "Fighting",
        "category": "Physical",
        "pp": 15,
        "power": "60",
        "acc": "85%",
    },
    28: {
        "name": "Sand Attack",
        "type": "Ground",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    29: {
        "name": "Headbutt",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "70",
        "acc": "100%",
    },
    30: {
        "name": "Horn Attack",
        "type": "Normal",
        "category": "Physical",
        "pp": 25,
        "power": "65",
        "acc": "100%",
    },
    31: {
        "name": "Fury Attack",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "15",
        "acc": "85%",
    },
    32: {
        "name": "Horn Drill",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "—",
        "acc": "30%",
    },
    33: {
        "name": "Tackle",
        "type": "Normal",
        "category": "Physical",
        "pp": 35,
        "power": "40",
        "acc": "100%",
    },
    34: {
        "name": "Body Slam",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "85",
        "acc": "100%",
    },
    35: {
        "name": "Wrap",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "15",
        "acc": "90%",
    },
    36: {
        "name": "Take Down",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "90",
        "acc": "85%",
    },
    37: {
        "name": "Thrash",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "120",
        "acc": "100%",
    },
    38: {
        "name": "Double-Edge",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "120",
        "acc": "100%",
    },
    39: {
        "name": "Tail Whip",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "100%",
    },
    40: {
        "name": "Poison Sting",
        "type": "Poison",
        "category": "Physical",
        "pp": 35,
        "power": "15",
        "acc": "100%",
    },
    41: {
        "name": "Twineedle",
        "type": "Bug",
        "category": "Physical",
        "pp": 20,
        "power": "25",
        "acc": "100%",
    },
    42: {
        "name": "Pin Missile",
        "type": "Bug",
        "category": "Physical",
        "pp": 20,
        "power": "25",
        "acc": "95%",
    },
    43: {
        "name": "Leer",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "100%",
    },
    44: {
        "name": "Bite",
        "type": "Dark",
        "category": "Physical",
        "pp": 25,
        "power": "60",
        "acc": "100%",
    },
    45: {
        "name": "Growl",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "100%",
    },
    46: {
        "name": "Roar",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    47: {
        "name": "Sing",
        "type": "Normal",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "55%",
    },
    48: {
        "name": "Supersonic",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "55%",
    },
    49: {
        "name": "Sonic Boom",
        "type": "Normal",
        "category": "Special",
        "pp": 20,
        "power": "—",
        "acc": "90%",
    },
    50: {
        "name": "Disable",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    51: {
        "name": "Acid",
        "type": "Poison",
        "category": "Special",
        "pp": 30,
        "power": "40",
        "acc": "100%",
    },
    52: {
        "name": "Ember",
        "type": "Fire",
        "category": "Special",
        "pp": 25,
        "power": "40",
        "acc": "100%",
    },
    53: {
        "name": "Flamethrower",
        "type": "Fire",
        "category": "Special",
        "pp": 15,
        "power": "90",
        "acc": "100%",
    },
    54: {
        "name": "Mist",
        "type": "Ice",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    55: {
        "name": "Water Gun",
        "type": "Water",
        "category": "Special",
        "pp": 25,
        "power": "40",
        "acc": "100%",
    },
    56: {
        "name": "Hydro Pump",
        "type": "Water",
        "category": "Special",
        "pp": 5,
        "power": "110",
        "acc": "80%",
    },
    57: {
        "name": "Surf",
        "type": "Water",
        "category": "Special",
        "pp": 15,
        "power": "90",
        "acc": "100%",
    },
    58: {
        "name": "Ice Beam",
        "type": "Ice",
        "category": "Special",
        "pp": 10,
        "power": "90",
        "acc": "100%",
    },
    59: {
        "name": "Blizzard",
        "type": "Ice",
        "category": "Special",
        "pp": 5,
        "power": "110",
        "acc": "70%",
    },
    60: {
        "name": "Psybeam",
        "type": "Psychic",
        "category": "Special",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    61: {
        "name": "Bubble Beam",
        "type": "Water",
        "category": "Special",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    62: {
        "name": "Aurora Beam",
        "type": "Ice",
        "category": "Special",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    63: {
        "name": "Hyper Beam",
        "type": "Normal",
        "category": "Special",
        "pp": 5,
        "power": "150",
        "acc": "90%",
    },
    64: {
        "name": "Peck",
        "type": "Flying",
        "category": "Physical",
        "pp": 35,
        "power": "35",
        "acc": "100%",
    },
    65: {
        "name": "Drill Peck",
        "type": "Flying",
        "category": "Physical",
        "pp": 20,
        "power": "80",
        "acc": "100%",
    },
    66: {
        "name": "Submission",
        "type": "Fighting",
        "category": "Physical",
        "pp": 20,
        "power": "80",
        "acc": "80%",
    },
    67: {
        "name": "Low Kick",
        "type": "Fighting",
        "category": "Physical",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    68: {
        "name": "Counter",
        "type": "Fighting",
        "category": "Physical",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    69: {
        "name": "Seismic Toss",
        "type": "Fighting",
        "category": "Physical",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    70: {
        "name": "Strength",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "80",
        "acc": "100%",
    },
    71: {
        "name": "Absorb",
        "type": "Grass",
        "category": "Special",
        "pp": 25,
        "power": "20",
        "acc": "100%",
    },
    72: {
        "name": "Mega Drain",
        "type": "Grass",
        "category": "Special",
        "pp": 15,
        "power": "40",
        "acc": "100%",
    },
    73: {
        "name": "Leech Seed",
        "type": "Grass",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "90%",
    },
    74: {
        "name": "Growth",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    75: {
        "name": "Razor Leaf",
        "type": "Grass",
        "category": "Physical",
        "pp": 25,
        "power": "55",
        "acc": "95%",
    },
    76: {
        "name": "Solar Beam",
        "type": "Grass",
        "category": "Special",
        "pp": 10,
        "power": "120",
        "acc": "100%",
    },
    77: {
        "name": "Poison Powder",
        "type": "Poison",
        "category": "Status",
        "pp": 35,
        "power": "—",
        "acc": "75%",
    },
    78: {
        "name": "Stun Spore",
        "type": "Grass",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "75%",
    },
    79: {
        "name": "Sleep Powder",
        "type": "Grass",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "75%",
    },
    80: {
        "name": "Petal Dance",
        "type": "Grass",
        "category": "Special",
        "pp": 10,
        "power": "120",
        "acc": "100%",
    },
    81: {
        "name": "String Shot",
        "type": "Bug",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "95%",
    },
    82: {
        "name": "Dragon Rage",
        "type": "Dragon",
        "category": "Special",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    83: {
        "name": "Fire Spin",
        "type": "Fire",
        "category": "Special",
        "pp": 15,
        "power": "35",
        "acc": "85%",
    },
    84: {
        "name": "Thunder Shock",
        "type": "Electric",
        "category": "Special",
        "pp": 30,
        "power": "40",
        "acc": "100%",
    },
    85: {
        "name": "Thunderbolt",
        "type": "Electric",
        "category": "Special",
        "pp": 15,
        "power": "90",
        "acc": "100%",
    },
    86: {
        "name": "Thunder Wave",
        "type": "Electric",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "90%",
    },
    87: {
        "name": "Thunder",
        "type": "Electric",
        "category": "Special",
        "pp": 10,
        "power": "110",
        "acc": "70%",
    },
    88: {
        "name": "Rock Throw",
        "type": "Rock",
        "category": "Physical",
        "pp": 15,
        "power": "50",
        "acc": "90%",
    },
    89: {
        "name": "Earthquake",
        "type": "Ground",
        "category": "Physical",
        "pp": 10,
        "power": "100",
        "acc": "100%",
    },
    90: {
        "name": "Fissure",
        "type": "Ground",
        "category": "Physical",
        "pp": 5,
        "power": "—",
        "acc": "30%",
    },
    91: {
        "name": "Dig",
        "type": "Ground",
        "category": "Physical",
        "pp": 10,
        "power": "80",
        "acc": "100%",
    },
    92: {
        "name": "Toxic",
        "type": "Poison",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "90%",
    },
    93: {
        "name": "Confusion",
        "type": "Psychic",
        "category": "Special",
        "pp": 25,
        "power": "50",
        "acc": "100%",
    },
    94: {
        "name": "Psychic",
        "type": "Psychic",
        "category": "Special",
        "pp": 10,
        "power": "90",
        "acc": "100%",
    },
    95: {
        "name": "Hypnosis",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "60%",
    },
    96: {
        "name": "Meditate",
        "type": "Psychic",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    97: {
        "name": "Agility",
        "type": "Psychic",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    98: {
        "name": "Quick Attack",
        "type": "Normal",
        "category": "Physical",
        "pp": 30,
        "power": "40",
        "acc": "100%",
    },
    99: {
        "name": "Rage",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "20",
        "acc": "100%",
    },
    100: {
        "name": "Teleport",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    101: {
        "name": "Night Shade",
        "type": "Ghost",
        "category": "Special",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    102: {
        "name": "Mimic",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    103: {
        "name": "Screech",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "85%",
    },
    104: {
        "name": "Double Team",
        "type": "Normal",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "—%",
    },
    105: {
        "name": "Recover",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    106: {
        "name": "Harden",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    107: {
        "name": "Minimize",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    108: {
        "name": "Smokescreen",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    109: {
        "name": "Confuse Ray",
        "type": "Ghost",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    110: {
        "name": "Withdraw",
        "type": "Water",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    111: {
        "name": "Defense Curl",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    112: {
        "name": "Barrier",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    113: {
        "name": "Light Screen",
        "type": "Psychic",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    114: {
        "name": "Haze",
        "type": "Ice",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    115: {
        "name": "Reflect",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    116: {
        "name": "Focus Energy",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    117: {
        "name": "Bide",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    118: {
        "name": "Metronome",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    119: {
        "name": "Mirror Move",
        "type": "Flying",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    120: {
        "name": "Self-Destruct",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "200",
        "acc": "100%",
    },
    121: {
        "name": "Egg Bomb",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "100",
        "acc": "75%",
    },
    122: {
        "name": "Lick",
        "type": "Ghost",
        "category": "Physical",
        "pp": 30,
        "power": "30",
        "acc": "100%",
    },
    123: {
        "name": "Smog",
        "type": "Poison",
        "category": "Special",
        "pp": 20,
        "power": "30",
        "acc": "70%",
    },
    124: {
        "name": "Sludge",
        "type": "Poison",
        "category": "Special",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    125: {
        "name": "Bone Club",
        "type": "Ground",
        "category": "Physical",
        "pp": 20,
        "power": "65",
        "acc": "85%",
    },
    126: {
        "name": "Fire Blast",
        "type": "Fire",
        "category": "Special",
        "pp": 5,
        "power": "110",
        "acc": "85%",
    },
    127: {
        "name": "Waterfall",
        "type": "Water",
        "category": "Physical",
        "pp": 15,
        "power": "80",
        "acc": "100%",
    },
    128: {
        "name": "Clamp",
        "type": "Water",
        "category": "Physical",
        "pp": 15,
        "power": "35",
        "acc": "85%",
    },
    129: {
        "name": "Swift",
        "type": "Normal",
        "category": "Special",
        "pp": 20,
        "power": "60",
        "acc": "—%",
    },
    130: {
        "name": "Skull Bash",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "130",
        "acc": "100%",
    },
    131: {
        "name": "Spike Cannon",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "20",
        "acc": "100%",
    },
    132: {
        "name": "Constrict",
        "type": "Normal",
        "category": "Physical",
        "pp": 35,
        "power": "10",
        "acc": "100%",
    },
    133: {
        "name": "Amnesia",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    134: {
        "name": "Kinesis",
        "type": "Psychic",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "80%",
    },
    135: {
        "name": "Soft-Boiled",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    136: {
        "name": "High Jump Kick",
        "type": "Fighting",
        "category": "Physical",
        "pp": 10,
        "power": "130",
        "acc": "90%",
    },
    137: {
        "name": "Glare",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "100%",
    },
    138: {
        "name": "Dream Eater",
        "type": "Psychic",
        "category": "Special",
        "pp": 15,
        "power": "100",
        "acc": "100%",
    },
    139: {
        "name": "Poison Gas",
        "type": "Poison",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "90%",
    },
    140: {
        "name": "Barrage",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "15",
        "acc": "85%",
    },
    141: {
        "name": "Leech Life",
        "type": "Bug",
        "category": "Physical",
        "pp": 10,
        "power": "80",
        "acc": "100%",
    },
    142: {
        "name": "Lovely Kiss",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "75%",
    },
    143: {
        "name": "Sky Attack",
        "type": "Flying",
        "category": "Physical",
        "pp": 5,
        "power": "140",
        "acc": "90%",
    },
    144: {
        "name": "Transform",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    145: {
        "name": "Bubble",
        "type": "Water",
        "category": "Special",
        "pp": 30,
        "power": "40",
        "acc": "100%",
    },
    146: {
        "name": "Dizzy Punch",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "70",
        "acc": "100%",
    },
    147: {
        "name": "Spore",
        "type": "Grass",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    148: {
        "name": "Flash",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    149: {
        "name": "Psywave",
        "type": "Psychic",
        "category": "Special",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    150: {
        "name": "Splash",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    151: {
        "name": "Acid Armor",
        "type": "Poison",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    152: {
        "name": "Crabhammer",
        "type": "Water",
        "category": "Physical",
        "pp": 10,
        "power": "100",
        "acc": "90%",
    },
    153: {
        "name": "Explosion",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "250",
        "acc": "100%",
    },
    154: {
        "name": "Fury Swipes",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "18",
        "acc": "80%",
    },
    155: {
        "name": "Bonemerang",
        "type": "Ground",
        "category": "Physical",
        "pp": 10,
        "power": "50",
        "acc": "90%",
    },
    156: {
        "name": "Rest",
        "type": "Psychic",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    157: {
        "name": "Rock Slide",
        "type": "Rock",
        "category": "Physical",
        "pp": 10,
        "power": "75",
        "acc": "90%",
    },
    158: {
        "name": "Hyper Fang",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "80",
        "acc": "90%",
    },
    159: {
        "name": "Sharpen",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    160: {
        "name": "Conversion",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    161: {
        "name": "Tri Attack",
        "type": "Normal",
        "category": "Special",
        "pp": 10,
        "power": "80",
        "acc": "100%",
    },
    162: {
        "name": "Super Fang",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "—",
        "acc": "90%",
    },
    163: {
        "name": "Slash",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "70",
        "acc": "100%",
    },
    164: {
        "name": "Substitute",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    165: {
        "name": "Struggle",
        "type": "Normal",
        "category": "Physical",
        "pp": 1,
        "power": "50",
        "acc": "—%",
    },
    166: {
        "name": "Sketch",
        "type": "Normal",
        "category": "Status",
        "pp": 1,
        "power": "—",
        "acc": "—%",
    },
    167: {
        "name": "Triple Kick",
        "type": "Fighting",
        "category": "Physical",
        "pp": 10,
        "power": "10",
        "acc": "90%",
    },
    168: {
        "name": "Thief",
        "type": "Dark",
        "category": "Physical",
        "pp": 25,
        "power": "60",
        "acc": "100%",
    },
    169: {
        "name": "Spider Web",
        "type": "Bug",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    170: {
        "name": "Mind Reader",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    171: {
        "name": "Nightmare",
        "type": "Ghost",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    172: {
        "name": "Flame Wheel",
        "type": "Fire",
        "category": "Physical",
        "pp": 25,
        "power": "60",
        "acc": "100%",
    },
    173: {
        "name": "Snore",
        "type": "Normal",
        "category": "Special",
        "pp": 15,
        "power": "50",
        "acc": "100%",
    },
    174: {
        "name": "Curse",
        "type": "Ghost",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    175: {
        "name": "Flail",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    176: {
        "name": "Conversion 2",
        "type": "Normal",
        "category": "Status",
        "pp": 30,
        "power": "—",
        "acc": "—%",
    },
    177: {
        "name": "Aeroblast",
        "type": "Flying",
        "category": "Special",
        "pp": 5,
        "power": "100",
        "acc": "95%",
    },
    178: {
        "name": "Cotton Spore",
        "type": "Grass",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "100%",
    },
    179: {
        "name": "Reversal",
        "type": "Fighting",
        "category": "Physical",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    180: {
        "name": "Spite",
        "type": "Ghost",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    181: {
        "name": "Powder Snow",
        "type": "Ice",
        "category": "Special",
        "pp": 25,
        "power": "40",
        "acc": "100%",
    },
    182: {
        "name": "Protect",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    183: {
        "name": "Mach Punch",
        "type": "Fighting",
        "category": "Physical",
        "pp": 30,
        "power": "40",
        "acc": "100%",
    },
    184: {
        "name": "Scary Face",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    185: {
        "name": "Feint Attack",
        "type": "Dark",
        "category": "Physical",
        "pp": 20,
        "power": "60",
        "acc": "—%",
    },
    186: {
        "name": "Sweet Kiss",
        "type": "Fairy",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "75%",
    },
    187: {
        "name": "Belly Drum",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    188: {
        "name": "Sludge Bomb",
        "type": "Poison",
        "category": "Special",
        "pp": 10,
        "power": "90",
        "acc": "100%",
    },
    189: {
        "name": "Mud-Slap",
        "type": "Ground",
        "category": "Special",
        "pp": 10,
        "power": "20",
        "acc": "100%",
    },
    190: {
        "name": "Octazooka",
        "type": "Water",
        "category": "Special",
        "pp": 10,
        "power": "65",
        "acc": "85%",
    },
    191: {
        "name": "Spikes",
        "type": "Ground",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    192: {
        "name": "Zap Cannon",
        "type": "Electric",
        "category": "Special",
        "pp": 5,
        "power": "120",
        "acc": "50%",
    },
    193: {
        "name": "Foresight",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    194: {
        "name": "Destiny Bond",
        "type": "Ghost",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    195: {
        "name": "Perish Song",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    196: {
        "name": "Icy Wind",
        "type": "Ice",
        "category": "Special",
        "pp": 15,
        "power": "55",
        "acc": "95%",
    },
    197: {
        "name": "Detect",
        "type": "Fighting",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    198: {
        "name": "Bone Rush",
        "type": "Ground",
        "category": "Physical",
        "pp": 10,
        "power": "25",
        "acc": "90%",
    },
    199: {
        "name": "Lock-On",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    200: {
        "name": "Outrage",
        "type": "Dragon",
        "category": "Physical",
        "pp": 10,
        "power": "120",
        "acc": "100%",
    },
    201: {
        "name": "Sandstorm",
        "type": "Rock",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    202: {
        "name": "Giga Drain",
        "type": "Grass",
        "category": "Special",
        "pp": 10,
        "power": "75",
        "acc": "100%",
    },
    203: {
        "name": "Endure",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    204: {
        "name": "Charm",
        "type": "Fairy",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    205: {
        "name": "Rollout",
        "type": "Rock",
        "category": "Physical",
        "pp": 20,
        "power": "30",
        "acc": "90%",
    },
    206: {
        "name": "False Swipe",
        "type": "Normal",
        "category": "Physical",
        "pp": 40,
        "power": "40",
        "acc": "100%",
    },
    207: {
        "name": "Swagger",
        "type": "Normal",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "85%",
    },
    208: {
        "name": "Milk Drink",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    209: {
        "name": "Spark",
        "type": "Electric",
        "category": "Physical",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    210: {
        "name": "Fury Cutter",
        "type": "Bug",
        "category": "Physical",
        "pp": 20,
        "power": "40",
        "acc": "95%",
    },
    211: {
        "name": "Steel Wing",
        "type": "Steel",
        "category": "Physical",
        "pp": 25,
        "power": "70",
        "acc": "90%",
    },
    212: {
        "name": "Mean Look",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    213: {
        "name": "Attract",
        "type": "Normal",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    214: {
        "name": "Sleep Talk",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    215: {
        "name": "Heal Bell",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    216: {
        "name": "Return",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    217: {
        "name": "Present",
        "type": "Normal",
        "category": "Physical",
        "pp": 15,
        "power": "—",
        "acc": "90%",
    },
    218: {
        "name": "Frustration",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    219: {
        "name": "Safeguard",
        "type": "Normal",
        "category": "Status",
        "pp": 25,
        "power": "—",
        "acc": "—%",
    },
    220: {
        "name": "Pain Split",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    221: {
        "name": "Sacred Fire",
        "type": "Fire",
        "category": "Physical",
        "pp": 5,
        "power": "100",
        "acc": "95%",
    },
    222: {
        "name": "Magnitude",
        "type": "Ground",
        "category": "Physical",
        "pp": 30,
        "power": "—",
        "acc": "100%",
    },
    223: {
        "name": "Dynamic Punch",
        "type": "Fighting",
        "category": "Physical",
        "pp": 5,
        "power": "100",
        "acc": "50%",
    },
    224: {
        "name": "Megahorn",
        "type": "Bug",
        "category": "Physical",
        "pp": 10,
        "power": "120",
        "acc": "85%",
    },
    225: {
        "name": "Dragon Breath",
        "type": "Dragon",
        "category": "Special",
        "pp": 20,
        "power": "60",
        "acc": "100%",
    },
    226: {
        "name": "Baton Pass",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    227: {
        "name": "Encore",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "100%",
    },
    228: {
        "name": "Pursuit",
        "type": "Dark",
        "category": "Physical",
        "pp": 20,
        "power": "40",
        "acc": "100%",
    },
    229: {
        "name": "Rapid Spin",
        "type": "Normal",
        "category": "Physical",
        "pp": 40,
        "power": "50",
        "acc": "100%",
    },
    230: {
        "name": "Sweet Scent",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    231: {
        "name": "Iron Tail",
        "type": "Steel",
        "category": "Physical",
        "pp": 15,
        "power": "100",
        "acc": "75%",
    },
    232: {
        "name": "Metal Claw",
        "type": "Steel",
        "category": "Physical",
        "pp": 35,
        "power": "50",
        "acc": "95%",
    },
    233: {
        "name": "Vital Throw",
        "type": "Fighting",
        "category": "Physical",
        "pp": 10,
        "power": "70",
        "acc": "—%",
    },
    234: {
        "name": "Morning Sun",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    235: {
        "name": "Synthesis",
        "type": "Grass",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    236: {
        "name": "Moonlight",
        "type": "Fairy",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    237: {
        "name": "Hidden Power",
        "type": "Normal",
        "category": "Special",
        "pp": 15,
        "power": "60",
        "acc": "100%",
    },
    238: {
        "name": "Cross Chop",
        "type": "Fighting",
        "category": "Physical",
        "pp": 5,
        "power": "100",
        "acc": "80%",
    },
    239: {
        "name": "Twister",
        "type": "Dragon",
        "category": "Special",
        "pp": 20,
        "power": "40",
        "acc": "100%",
    },
    240: {
        "name": "Rain Dance",
        "type": "Water",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    241: {
        "name": "Sunny Day",
        "type": "Fire",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    242: {
        "name": "Crunch",
        "type": "Dark",
        "category": "Physical",
        "pp": 15,
        "power": "80",
        "acc": "100%",
    },
    243: {
        "name": "Mirror Coat",
        "type": "Psychic",
        "category": "Special",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    244: {
        "name": "Psych Up",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    245: {
        "name": "Extreme Speed",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "80",
        "acc": "100%",
    },
    246: {
        "name": "Ancient Power",
        "type": "Rock",
        "category": "Special",
        "pp": 5,
        "power": "60",
        "acc": "100%",
    },
    247: {
        "name": "Shadow Ball",
        "type": "Ghost",
        "category": "Special",
        "pp": 15,
        "power": "80",
        "acc": "100%",
    },
    248: {
        "name": "Future Sight",
        "type": "Psychic",
        "category": "Special",
        "pp": 10,
        "power": "120",
        "acc": "100%",
    },
    249: {
        "name": "Rock Smash",
        "type": "Fighting",
        "category": "Physical",
        "pp": 15,
        "power": "40",
        "acc": "100%",
    },
    250: {
        "name": "Whirlpool",
        "type": "Water",
        "category": "Special",
        "pp": 15,
        "power": "35",
        "acc": "85%",
    },
    251: {
        "name": "Beat Up",
        "type": "Dark",
        "category": "Physical",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    252: {
        "name": "Fake Out",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "40",
        "acc": "100%",
    },
    253: {
        "name": "Uproar",
        "type": "Normal",
        "category": "Special",
        "pp": 10,
        "power": "90",
        "acc": "100%",
    },
    254: {
        "name": "Stockpile",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    255: {
        "name": "Spit Up",
        "type": "Normal",
        "category": "Special",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    256: {
        "name": "Swallow",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    257: {
        "name": "Heat Wave",
        "type": "Fire",
        "category": "Special",
        "pp": 10,
        "power": "95",
        "acc": "90%",
    },
    258: {
        "name": "Hail",
        "type": "Ice",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    259: {
        "name": "Torment",
        "type": "Dark",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    260: {
        "name": "Flatter",
        "type": "Dark",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    261: {
        "name": "Will-O-Wisp",
        "type": "Fire",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "85%",
    },
    262: {
        "name": "Memento",
        "type": "Dark",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    263: {
        "name": "Facade",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "70",
        "acc": "100%",
    },
    264: {
        "name": "Focus Punch",
        "type": "Fighting",
        "category": "Physical",
        "pp": 20,
        "power": "150",
        "acc": "100%",
    },
    265: {
        "name": "Smelling Salts",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "70",
        "acc": "100%",
    },
    266: {
        "name": "Follow Me",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    267: {
        "name": "Nature Power",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    268: {
        "name": "Charge",
        "type": "Electric",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    269: {
        "name": "Taunt",
        "type": "Dark",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    270: {
        "name": "Helping Hand",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    271: {
        "name": "Trick",
        "type": "Psychic",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "100%",
    },
    272: {
        "name": "Role Play",
        "type": "Psychic",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    273: {
        "name": "Wish",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    274: {
        "name": "Assist",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    275: {
        "name": "Ingrain",
        "type": "Grass",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    276: {
        "name": "Superpower",
        "type": "Fighting",
        "category": "Physical",
        "pp": 5,
        "power": "120",
        "acc": "100%",
    },
    277: {
        "name": "Magic Coat",
        "type": "Psychic",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "—%",
    },
    278: {
        "name": "Recycle",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    279: {
        "name": "Revenge",
        "type": "Fighting",
        "category": "Physical",
        "pp": 10,
        "power": "60",
        "acc": "100%",
    },
    280: {
        "name": "Brick Break",
        "type": "Fighting",
        "category": "Physical",
        "pp": 15,
        "power": "75",
        "acc": "100%",
    },
    281: {
        "name": "Yawn",
        "type": "Normal",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    282: {
        "name": "Knock Off",
        "type": "Dark",
        "category": "Physical",
        "pp": 20,
        "power": "65",
        "acc": "100%",
    },
    283: {
        "name": "Endeavor",
        "type": "Normal",
        "category": "Physical",
        "pp": 5,
        "power": "—",
        "acc": "100%",
    },
    284: {
        "name": "Eruption",
        "type": "Fire",
        "category": "Special",
        "pp": 5,
        "power": "150",
        "acc": "100%",
    },
    285: {
        "name": "Skill Swap",
        "type": "Psychic",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    286: {
        "name": "Imprison",
        "type": "Psychic",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    287: {
        "name": "Refresh",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    288: {
        "name": "Grudge",
        "type": "Ghost",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    289: {
        "name": "Snatch",
        "type": "Dark",
        "category": "Status",
        "pp": 10,
        "power": "—",
        "acc": "—%",
    },
    290: {
        "name": "Secret Power",
        "type": "Normal",
        "category": "Physical",
        "pp": 20,
        "power": "70",
        "acc": "100%",
    },
    291: {
        "name": "Dive",
        "type": "Water",
        "category": "Physical",
        "pp": 10,
        "power": "80",
        "acc": "100%",
    },
    292: {
        "name": "Arm Thrust",
        "type": "Fighting",
        "category": "Physical",
        "pp": 20,
        "power": "15",
        "acc": "100%",
    },
    293: {
        "name": "Camouflage",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    294: {
        "name": "Tail Glow",
        "type": "Bug",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    295: {
        "name": "Luster Purge",
        "type": "Psychic",
        "category": "Special",
        "pp": 5,
        "power": "70",
        "acc": "100%",
    },
    296: {
        "name": "Mist Ball",
        "type": "Psychic",
        "category": "Special",
        "pp": 5,
        "power": "70",
        "acc": "100%",
    },
    297: {
        "name": "Feather Dance",
        "type": "Flying",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "100%",
    },
    298: {
        "name": "Teeter Dance",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    299: {
        "name": "Blaze Kick",
        "type": "Fire",
        "category": "Physical",
        "pp": 10,
        "power": "85",
        "acc": "90%",
    },
    300: {
        "name": "Mud Sport",
        "type": "Ground",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "—%",
    },
    301: {
        "name": "Ice Ball",
        "type": "Ice",
        "category": "Physical",
        "pp": 20,
        "power": "30",
        "acc": "90%",
    },
    302: {
        "name": "Needle Arm",
        "type": "Grass",
        "category": "Physical",
        "pp": 15,
        "power": "60",
        "acc": "100%",
    },
    303: {
        "name": "Slack Off",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    304: {
        "name": "Hyper Voice",
        "type": "Normal",
        "category": "Special",
        "pp": 10,
        "power": "90",
        "acc": "100%",
    },
    305: {
        "name": "Poison Fang",
        "type": "Poison",
        "category": "Physical",
        "pp": 15,
        "power": "50",
        "acc": "100%",
    },
    306: {
        "name": "Crush Claw",
        "type": "Normal",
        "category": "Physical",
        "pp": 10,
        "power": "75",
        "acc": "95%",
    },
    307: {
        "name": "Blast Burn",
        "type": "Fire",
        "category": "Special",
        "pp": 5,
        "power": "150",
        "acc": "90%",
    },
    308: {
        "name": "Hydro Cannon",
        "type": "Water",
        "category": "Special",
        "pp": 5,
        "power": "150",
        "acc": "90%",
    },
    309: {
        "name": "Meteor Mash",
        "type": "Steel",
        "category": "Physical",
        "pp": 10,
        "power": "90",
        "acc": "90%",
    },
    310: {
        "name": "Astonish",
        "type": "Ghost",
        "category": "Physical",
        "pp": 15,
        "power": "30",
        "acc": "100%",
    },
    311: {
        "name": "Weather Ball",
        "type": "Normal",
        "category": "Special",
        "pp": 10,
        "power": "50",
        "acc": "100%",
    },
    312: {
        "name": "Aromatherapy",
        "type": "Grass",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    313: {
        "name": "Fake Tears",
        "type": "Dark",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    314: {
        "name": "Air Cutter",
        "type": "Flying",
        "category": "Special",
        "pp": 25,
        "power": "60",
        "acc": "95%",
    },
    315: {
        "name": "Overheat",
        "type": "Fire",
        "category": "Special",
        "pp": 5,
        "power": "130",
        "acc": "90%",
    },
    316: {
        "name": "Odor Sleuth",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    317: {
        "name": "Rock Tomb",
        "type": "Rock",
        "category": "Physical",
        "pp": 15,
        "power": "60",
        "acc": "95%",
    },
    318: {
        "name": "Silver Wind",
        "type": "Bug",
        "category": "Special",
        "pp": 5,
        "power": "60",
        "acc": "100%",
    },
    319: {
        "name": "Metal Sound",
        "type": "Steel",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "85%",
    },
    320: {
        "name": "Grass Whistle",
        "type": "Grass",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "55%",
    },
    321: {
        "name": "Tickle",
        "type": "Normal",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "100%",
    },
    322: {
        "name": "Cosmic Power",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    323: {
        "name": "Water Spout",
        "type": "Water",
        "category": "Special",
        "pp": 5,
        "power": "150",
        "acc": "100%",
    },
    324: {
        "name": "Signal Beam",
        "type": "Bug",
        "category": "Special",
        "pp": 15,
        "power": "75",
        "acc": "100%",
    },
    325: {
        "name": "Shadow Punch",
        "type": "Ghost",
        "category": "Physical",
        "pp": 20,
        "power": "60",
        "acc": "—%",
    },
    326: {
        "name": "Extrasensory",
        "type": "Psychic",
        "category": "Special",
        "pp": 20,
        "power": "80",
        "acc": "100%",
    },
    327: {
        "name": "Sky Uppercut",
        "type": "Fighting",
        "category": "Physical",
        "pp": 15,
        "power": "85",
        "acc": "90%",
    },
    328: {
        "name": "Sand Tomb",
        "type": "Ground",
        "category": "Physical",
        "pp": 15,
        "power": "35",
        "acc": "85%",
    },
    329: {
        "name": "Sheer Cold",
        "type": "Ice",
        "category": "Special",
        "pp": 5,
        "power": "—",
        "acc": "30%",
    },
    330: {
        "name": "Muddy Water",
        "type": "Water",
        "category": "Special",
        "pp": 10,
        "power": "90",
        "acc": "85%",
    },
    331: {
        "name": "Bullet Seed",
        "type": "Grass",
        "category": "Physical",
        "pp": 30,
        "power": "25",
        "acc": "100%",
    },
    332: {
        "name": "Aerial Ace",
        "type": "Flying",
        "category": "Physical",
        "pp": 20,
        "power": "60",
        "acc": "—",
    },
    333: {
        "name": "Icicle Spear",
        "type": "Ice",
        "category": "Physical",
        "pp": 30,
        "power": "25",
        "acc": "100%",
    },
    334: {
        "name": "Iron Defense",
        "type": "Steel",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "—%",
    },
    335: {
        "name": "Block",
        "type": "Normal",
        "category": "Status",
        "pp": 5,
        "power": "—",
        "acc": "—%",
    },
    336: {
        "name": "Howl",
        "type": "Normal",
        "category": "Status",
        "pp": 40,
        "power": "—",
        "acc": "—%",
    },
    337: {
        "name": "Dragon Claw",
        "type": "Dragon",
        "category": "Physical",
        "pp": 15,
        "power": "80",
        "acc": "100%",
    },
    338: {
        "name": "Frenzy Plant",
        "type": "Grass",
        "category": "Special",
        "pp": 5,
        "power": "150",
        "acc": "90%",
    },
    339: {
        "name": "Bulk Up",
        "type": "Fighting",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    340: {
        "name": "Bounce",
        "type": "Flying",
        "category": "Physical",
        "pp": 5,
        "power": "85",
        "acc": "85%",
    },
    341: {
        "name": "Mud Shot",
        "type": "Ground",
        "category": "Special",
        "pp": 15,
        "power": "55",
        "acc": "95%",
    },
    342: {
        "name": "Poison Tail",
        "type": "Poison",
        "category": "Physical",
        "pp": 25,
        "power": "50",
        "acc": "100%",
    },
    343: {
        "name": "Covet",
        "type": "Normal",
        "category": "Physical",
        "pp": 25,
        "power": "60",
        "acc": "100%",
    },
    344: {
        "name": "Volt Tackle",
        "type": "Electric",
        "category": "Physical",
        "pp": 15,
        "power": "120",
        "acc": "100%",
    },
    345: {
        "name": "Magical Leaf",
        "type": "Grass",
        "category": "Special",
        "pp": 20,
        "power": "60",
        "acc": "—%",
    },
    346: {
        "name": "Water Sport",
        "type": "Water",
        "category": "Status",
        "pp": 15,
        "power": "—",
        "acc": "—%",
    },
    347: {
        "name": "Calm Mind",
        "type": "Psychic",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    348: {
        "name": "Leaf Blade",
        "type": "Grass",
        "category": "Physical",
        "pp": 15,
        "power": "90",
        "acc": "100%",
    },
    349: {
        "name": "Dragon Dance",
        "type": "Dragon",
        "category": "Status",
        "pp": 20,
        "power": "—",
        "acc": "—%",
    },
    350: {
        "name": "Rock Blast",
        "type": "Rock",
        "category": "Physical",
        "pp": 10,
        "power": "25",
        "acc": "90%",
    },
    351: {
        "name": "Shock Wave",
        "type": "Electric",
        "category": "Special",
        "pp": 20,
        "power": "60",
        "acc": "—%",
    },
    352: {
        "name": "Water Pulse",
        "type": "Water",
        "category": "Special",
        "pp": 20,
        "power": "60",
        "acc": "100%",
    },
    353: {
        "name": "Doom Desire",
        "type": "Steel",
        "category": "Special",
        "pp": 5,
        "power": "140",
        "acc": "100%",
    },
    354: {
        "name": "Psycho Boost",
        "type": "Psychic",
        "category": "Special",
        "pp": 5,
        "power": "140",
        "acc": "90%",
    },
}

INT_TO_MOVE = {k: v["name"] for k, v in MOVES.items()}

MOVE_TO_INT = {v: k for k, v in INT_TO_MOVE.items()}

NAME_TO_DATA = {}
for key, value in MOVES.items():
    name = value.pop("name")
    value["index"] = key
    NAME_TO_DATA[name] = value
